==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_el.ts <==
<TS language="el" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Δημιουργία νέου λογαριασμού</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Εισάγετε συνθηματικό</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Νέο συνθηματικό</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Επαναλάβετε νέο συνθηματικό</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Αλλαγή συνθηματικού</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Πορτοφόλι</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Αντιγραφή διεύθυνσης</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Αντιγραφή ποσού</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Αντιγραφή ποσότητας</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Αντιγραφή αλλαγής</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>έκδοση</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Καλώς Ήλθατε</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>W&amp;allet</source>
        <translation>Πορτοφόλι</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Services</source>
        <translation>Υπηρεσίες</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>Αντιγραφή μηνύματος</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Αντιγραφή ποσού</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Μήνυμα</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Μήνυμα</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(κανένα μήνυμα)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>Κεφάλαια μη επαρκή</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Συνίσταται:</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Αντιγραφή ποσότητας</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Αντιγραφή ποσού</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Αντιγραφή αλλαγής</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Message:</source>
        <translation>Μήνυμα:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Μήνυμα</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy address</source>
        <translation>Αντιγραφή διεύθυνσης</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Αντιγραφή ποσού</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>Κεφάλαια μη επαρκή</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Φόρτωση πορτοφολιού...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Επανάληψη σάρωσης</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Η φόρτωση ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
</TS>

==> bitcoin-0.13.1.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_el.ts <==
<TS language="el" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Δημιουργία νέου λογαριασμού</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Εισάγετε συνθηματικό</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Νέο συνθηματικό</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Επαναλάβετε νέο συνθηματικό</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Πορτοφόλι</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Date</source>
        <translation>Ημερομηνία</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Διεύθυνση</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>έκδοση</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Καλώς Ήλθατε</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>W&amp;allet</source>
        <translation>Πορτοφόλι</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Services</source>
        <translation>Υπηρεσίες</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Insufficient funds!</source>
        <translation>Κεφάλαια μη επαρκή</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Συνίσταται:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Message:</source>
        <translation>Μήνυμα:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>Κεφάλαια μη επαρκή</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Φόρτωση πορτοφολιού...</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Επανάληψη σάρωσης</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Η φόρτωση ολοκληρώθηκε</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
</context>
</TS>
